<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl_PL">
<context>
    <name>DecoderMPEGFactory</name>
    <message>
        <location filename="../decodermpegfactory.cpp" line="179"/>
        <source>MPEG Plugin</source>
        <translation>Wtyczka MPEG</translation>
    </message>
    <message>
        <location filename="../decodermpegfactory.cpp" line="182"/>
        <source>MPEG Files</source>
        <translation>Pliki MPEG</translation>
    </message>
    <message>
        <location filename="../decodermpegfactory.cpp" line="400"/>
        <source>About MPEG Audio Plugin</source>
        <translation>O wtyczce dźwiękowej MPEG</translation>
    </message>
    <message>
        <location filename="../decodermpegfactory.cpp" line="401"/>
        <source>MPEG 1.0/2.0/2.5 layer 1/2/3 audio decoder</source>
        <translation>Dekoder dźwięku MPEG 1.0/2.0/2.5 layer 1/2/3</translation>
    </message>
    <message>
        <location filename="../decodermpegfactory.cpp" line="402"/>
        <source>Compiled against:</source>
        <translation>Skompilowana z biblioteką:</translation>
    </message>
    <message>
        <location filename="../decodermpegfactory.cpp" line="411"/>
        <source>mpg123, API version: %1</source>
        <translation>mpg123, wersja API: %1</translation>
    </message>
    <message>
        <location filename="../decodermpegfactory.cpp" line="415"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation>Napisane przez: Ilya Kotov &lt;forkotov02@ya.ru&gt;</translation>
    </message>
    <message>
        <location filename="../decodermpegfactory.cpp" line="416"/>
        <source>Source code based on mq3 and madplay projects</source>
        <translation>Kod źródłowy oparty na projektach mq3 oraz madplay</translation>
    </message>
</context>
<context>
    <name>MPEGMetaDataModel</name>
    <message>
        <location filename="../mpegmetadatamodel.cpp" line="65"/>
        <location filename="../mpegmetadatamodel.cpp" line="68"/>
        <location filename="../mpegmetadatamodel.cpp" line="71"/>
        <location filename="../mpegmetadatamodel.cpp" line="74"/>
        <source>Mode</source>
        <translation>Tryb</translation>
    </message>
    <message>
        <location filename="../mpegmetadatamodel.cpp" line="77"/>
        <source>Protection</source>
        <translation>Zabezpieczenie</translation>
    </message>
    <message>
        <location filename="../mpegmetadatamodel.cpp" line="78"/>
        <source>Copyright</source>
        <translation>Prawa autorskie</translation>
    </message>
    <message>
        <location filename="../mpegmetadatamodel.cpp" line="79"/>
        <source>Original</source>
        <translation>Oryginał</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>MPEG Plugin Settings</source>
        <translation>Ustawienia wtyczki MPEG</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="35"/>
        <source>Decoder</source>
        <translation>Dekoder</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="41"/>
        <source>MAD</source>
        <translation>MAD</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="48"/>
        <source>MPG123</source>
        <translation>MPG123</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="77"/>
        <source>Tag Priority</source>
        <translation>Priorytet tagów</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="89"/>
        <source>First:</source>
        <translation>Pierwszy:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="109"/>
        <location filename="../settingsdialog.ui" line="158"/>
        <location filename="../settingsdialog.ui" line="207"/>
        <source>ID3v1</source>
        <translation>ID3v1</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="114"/>
        <location filename="../settingsdialog.ui" line="163"/>
        <location filename="../settingsdialog.ui" line="212"/>
        <source>ID3v2</source>
        <translation>ID3v2</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="119"/>
        <location filename="../settingsdialog.ui" line="168"/>
        <location filename="../settingsdialog.ui" line="217"/>
        <source>APE</source>
        <translation>APE</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="124"/>
        <location filename="../settingsdialog.ui" line="173"/>
        <location filename="../settingsdialog.ui" line="222"/>
        <source>Disabled</source>
        <translation>Wyłączone</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="138"/>
        <source>Second:</source>
        <translation>Drugi:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="187"/>
        <source>Third:</source>
        <translation>Trzeci:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="243"/>
        <source>Merge selected tag types</source>
        <translation>Scal wybrane typy tagów</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="262"/>
        <source>Encodings</source>
        <translation>Kodowania</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="274"/>
        <source>ID3v1 encoding:</source>
        <translation>Kodowanie ID3v1:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="300"/>
        <source>ID3v2 encoding:</source>
        <translation>Kodowanie ID3v2:</translation>
    </message>
</context>
</TS>
